package weimob

import (
	"encoding/json"
	"errors"
)

func (w *WeimobConfig) RightsDetial(accessToken, rightsId string) (res RightsDetialRes, err error) {

	url := w.ApiUrl + "api/1_0/ec/rights/getRightsOrderDetail?accesstoken=" + accessToken
	query := map[string]interface{}{"id": rightsId}
	queryBody, err := json.Marshal(query)
	if err != nil {
		return
	}
	queryData := w.PostJSON(url, queryBody)
	err = json.Unmarshal([]byte(queryData), &res)
	return
}

//拒绝售后
func (w *WeimobConfig) AfterSaleRefuse(accesstoken string, id int64, refusedReason string) (res string, err error) {
	if id <= 0 {
		err = errors.New("售后id不能为空")
		return
	}
	deliveryParams := map[string]interface{}{
		"id":            id,
		"cancelType":    2,
		"refusedReason": "售后申请被拒绝",
	}
	if len(refusedReason) > 0 {
		deliveryParams["refusedReason"] = refusedReason
	}
	url := w.ApiUrl + "api/1_0/ec/rights/cancelRightsOrder?accesstoken=" + accesstoken
	body, err := json.Marshal(deliveryParams)
	if err != nil {
		return
	}
	res = w.PostJSON(url, body)
	return
}

//同意售后
func (w *WeimobConfig) AfterSaleAgree(accesstoken string, id, rightsType int64) (res string, err error) {
	if id <= 0 {
		err = errors.New("售后id不能为空")
		return
	}
	if rightsType != 1 && rightsType != 2 && rightsType != 5 {
		err = errors.New("售后id不能为空")
		return
	}
	deliveryParams := map[string]interface{}{
		"id":         id,
		"rightsType": rightsType,
	}
	url := w.ApiUrl + "api/1_0/ec/rights/agreeRightsOrder?accesstoken=" + accesstoken
	body, err := json.Marshal(deliveryParams)
	if err != nil {
		return
	}
	res = w.PostJSON(url, body)
	return
}

//商家确认收货  a
func (w *WeimobConfig) ConfirmReceivedRightsGoods(accesstoken string, id int64) (res string, err error) {
	if id <= 0 {
		err = errors.New("售后id不能为空")
		return
	}
	deliveryParams := map[string]interface{}{
		"id": id,
	}
	url := w.ApiUrl + "api/1_0/ec/rights/confirmReceivedRightsGoods?accesstoken=" + accesstoken
	body, err := json.Marshal(deliveryParams)
	if err != nil {
		return
	}
	res = w.PostJSON(url, body)
	return
}
