package weimob

import (
	"encoding/json"
)

func (w *WeimobConfig) GetSkuId(accesstoken string, outerSkuCode int, storeId string) (res *GetSkuIdRes, err error) {

	url := w.ApiUrl + "api/1_0/ec/singleProduct/queryProductListBySkuCode?accesstoken=" + accesstoken
	data := w.DoPost(url, map[string]interface{}{"skuCode": outerSkuCode, "storeId": storeId})
	err = json.Unmarshal([]byte(data), &res)
	return
}

func (w *WeimobConfig) UpdatePrice(accesstoken string, req map[string]interface{}) (res *WeimobRes, err error) {
	url := w.ApiUrl + "api/1_0/ec/retailGoods/updatePrice?accesstoken=" + accesstoken
	data := w.DoPost(url, req)
	err = json.Unmarshal([]byte(data), &res)
	return
}

func (w *WeimobConfig) UpdateStock(accesstoken string, req map[string]interface{}) (res *WeimobRes, err error) {
	url := w.ApiUrl + "api/1_0/ec/goods/updateStock?accesstoken=" + accesstoken
	data := w.DoPost(url, req)
	err = json.Unmarshal([]byte(data), &res)
	return
}
func (w *WeimobConfig) GoodsDetail(accesstoken, goodId string) (res *WeimobGoodsDetialResult, err error) {
	url := w.ApiUrl + "api/1_0/ec/goods/queryGoodsDetail?accesstoken=" + accesstoken
	body, _ := json.Marshal(map[string]string{"goodsId": goodId})
	data := w.PostJSON(url, body)
	err = json.Unmarshal([]byte(data), &res)
	return
}

//查询模板
func (w *WeimobConfig) FindFreightTemplateList(accesstoken string) (res *FindFreightTemplateListRes, err error) {
	url := w.ApiUrl + "api/1_0/ec/goods/findFreightTemplateList?accesstoken=" + accesstoken
	data := w.DoPost(url, map[string]interface{}{})
	err = json.Unmarshal([]byte(data), &res)
	return
}

//查询快递
func (w *WeimobConfig) FindDeliveryTypeList(accesstoken string) (res *FindDeliveryTypeListRes, err error) {
	url := w.ApiUrl + "api/1_0/ec/goods/findDeliveryTypeList?accesstoken=" + accesstoken
	data := w.DoPost(url, map[string]interface{}{})
	err = json.Unmarshal([]byte(data), &res)
	return
}

//查询sku
func (w *WeimobConfig) CategoryAttrInfo(accesstoken string, deliveryParams map[string]interface{}) (res *CategoryAttrInfoRes, err error) {
	url := w.ApiUrl + "api/1_0/ec/category/queryCategoryAttrInfo?accesstoken=" + accesstoken
	queryBody, err := json.Marshal(deliveryParams)
	if err != nil {
		return
	}
	queryData := w.PostJSON(url, queryBody)
	err = json.Unmarshal([]byte(queryData), &res)
	return
}

//添加sku
func (w *WeimobConfig) AddAttributeName(accesstoken string, deliveryParams map[string]interface{}) (res *AddAttributeNameRes, err error) {
	url := w.ApiUrl + "api/1_0/ec/category/addAttribute?accesstoken=" + accesstoken
	body, err := json.Marshal(deliveryParams)
	if err != nil {
		return
	}
	data := w.PostJSON(url, body)
	err = json.Unmarshal([]byte(data), &res)
	return
}

//添加sku值
func (w *WeimobConfig) AddAttributeValue(accesstoken string, deliveryParams map[string]interface{}) (res *AddAttributeValueRes, err error) {
	url := w.ApiUrl + "api/1_0/ec/category/addAttrValue?accesstoken=" + accesstoken
	body, err := json.Marshal(deliveryParams)
	if err != nil {
		return
	}
	data := w.PostJSON(url, body)
	err = json.Unmarshal([]byte(data), &res)
	return
}

func (w *WeimobConfig) Add(accesstoken string, good map[string]interface{}) (res *WeimobGoodsResult, err error) {
	url := w.ApiUrl + "api/1_0/ec/goods/addGoods?accesstoken=" + accesstoken
	body, err := json.Marshal(good)
	if err != nil {
		return
	}
	data := w.PostJSON(url, body)
	err = json.Unmarshal([]byte(data), &res)
	return
}
func (w *WeimobConfig) Update(accesstoken string, good map[string]interface{}) (res *WeimobGoodsResult, err error) {
	url := w.ApiUrl + "api/1_0/ec/goods/updateGoods?accesstoken=" + accesstoken
	body, err := json.Marshal(good)
	if err != nil {
		return
	}
	data := w.PostJSON(url, body)
	err = json.Unmarshal([]byte(data), &res)
	return
}

func (w *WeimobConfig) Dels(accesstoken string, goodIds []int64) (res *WeimobGoodsDelResult, err error) {
	url := w.ApiUrl + "api/1_0/ec/goods/deleteGoods?accesstoken=" + accesstoken
	body, _ := json.Marshal(map[string][]int64{"goodsIdList": goodIds})
	data := w.PostJSON(url, body)
	err = json.Unmarshal([]byte(data), &res)
	return
}

func (w *WeimobConfig) CategoryTree(accesstoken string) (res *Result, err error) {
	url := w.ApiUrl + "api/1_0/ec/category/queryCategoryTree?accesstoken=" + accesstoken
	data := w.DoPost(url, map[string]interface{}{})
	err = json.Unmarshal([]byte(data), &res)
	return
}
func (w *WeimobConfig) ChildrenCategory(accesstoken string, categoryId int) (res *Result, err error) {
	url := w.ApiUrl + "api/1_0/ec/category/queryChildrenCategory?accesstoken=" + accesstoken
	body := map[string]interface{}{
		"categoryId": categoryId,
	}
	data, _ := json.Marshal(body)
	r := w.PostJSON(url, data)
	err = json.Unmarshal([]byte(r), &res)
	return
}
